@@ -135,6 +135,8 @@ class QueryCondition:
                 "be made up of one or more Boolean expressions."
             )
 
+        return query_attrs
+
 
 @dataclass
 class QueryConditionTree(ast.NodeVisitor):
@@ -318,10 +320,7 @@ class QueryConditionTree(ast.NodeVisitor):
             raise tiledb.TileDBError(f"Attribute `{att}` not found in schema.")
 
         if att not in self.query_attrs:
-            raise tiledb.TileDBError(
-                f"Attribute `{att}` given to filter in query's `attr_cond` "
-                "arg but not found in `attr` arg."
-            )
+            self.query_attrs.append(att)
 
         return att
 
